@@ -33,7 +33,7 @@ use Try::Tiny;
 # version
 # ****************************************************************
 
-our $VERSION = "0.01";
+our $VERSION = "0.02";
 
 
 # ****************************************************************
@@ -351,13 +351,13 @@ __END__
 
 =head1 NAME
 
-Lingua::EO::Orthography - A converter of notations (orthography and substitute notations) for Esperanto characters
+Lingua::EO::Orthography - A orthography/substitute converter for Esperanto characters
 
 =head1 VERSION
 
 This document describes
 L<Lingua::EO::Orthography|Lingua::EO::Orthography>
-version C<0.00>.
+version C<0.02>.
 
 =head2 Translations
 
@@ -365,7 +365,8 @@ version C<0.00>.
 
 =item en: English
 
-L<Lingua::EO::Orthography|Lingua::EO::Orthography> (This document)
+L<Lingua::EO::Orthography|Lingua::EO::Orthography>
+(This document)
 
 =item eo: Esperanto
 
@@ -397,7 +398,7 @@ L<Lingua::EO::Orthography::JA|Lingua::EO::Orthography::JA>
         #     sources => [qw(orthography)],
         #     target  => 'postfix_x',
         # );
-    $original  = q(Ĉi-momente, la sonĝa ĥoraĵo ŝprucigas aplaŭdon);
+    $original  = q(ﾄ・-momente, la sonﾄ拌 ﾄ･oraﾄｵo ﾅ挾rucigas aplaﾅｭdon);
     $converted = $converter->convert($original);
 
 =head1 DESCRIPTION
@@ -431,7 +432,7 @@ and you will can add notations except them.
 
 =item C<orthography>
 
-    Ĉ ĉ Ĝ ĝ Ĥ ĥ Ĵ ĵ Ŝ ŝ Ŭ ŭ
+    ﾄ蠀 ﾄ褀 ﾄ鰀 ﾄ鴀 ﾄ､ ﾄ･ ﾄｴ ﾄｵ ﾅ鰀 ﾅ鴀 ﾅｬ ﾅｭ
 
     (\x{108} \x{109} \x{11C} \x{11D} \x{124} \x{125}
      \x{134} \x{135} \x{15C} \x{15D} \x{16C} \x{16D})
@@ -522,7 +523,7 @@ It places a capital C<X> as a postfix of a capital alphabet.
 
 It is a substitute notation, which places a caret C<^> as a postfix.
 
-People called it I<caret system> (eo: I<ĉapelita sistemo>).
+People called it I<caret system> (eo: I<ﾄ餌pelita sistemo>).
 
 People often use it as a substitute notation,
 because caret have the same shape as circumflex.
@@ -553,7 +554,7 @@ I compare them by the following list:
 
  Viewpoints                 ::Supersignoj   ::Orthography               Note
  -------------------------- --------------- --------------------------- ----
- Version                    0.02            0.00
+ Version                    0.02            0.02
  Can convert @lines         Yes             No                          *1
  Have accessors             Yes             Yes, and it has utilities   *2
  Can customize notation     Only 'u'        No (under consideration)    *3
@@ -720,6 +721,35 @@ the converter throws an exception.
 
 =back
 
+=head2 Accessors
+
+=head3 C<< sources >>
+
+    $source_notations_ref = $converter->sources;
+
+Returns source notations as an array reference.
+If you want to get it as a list, you can use L<all_sources()|/all_sources>.
+
+    $source_notations_ref = $converter->sources(\@notations);
+
+Accepts an array reference as source notations.
+You can use notations as L<new()|/new> constructor.
+
+Return value is the same as when an argument was not passed.
+
+=head3 C<< target >>
+
+    $target_notation = $converter->target;
+
+Returns target notation as a scalar.
+
+    $target_notation = $converter->target($notation);
+
+Accepts a string as target notation.
+You can use notations as L<new()|/new> constructor.
+
+Return value is the same as when an argument was not passed.
+
 =head2 Converter
 
 =head3 C<< convert >>
@@ -750,35 +780,6 @@ See RFC 2396 and 3986 for URI, and see RFC 5321 and 5322 for e-mail address.
 I described a concrete example to
 F<examples/ignore_addresses.pl> in the distribution.
 
-=head2 Accessors
-
-=head3 C<< sources >>
-
-    $source_notations_ref = $converter->sources;
-
-Returns source notations as an array reference.
-If you want to get it as a list, you can use L<all_sources()|/all_sources>.
-
-    $source_notations_ref = $converter->sources(\@notations);
-
-Accepts an array reference as source notations.
-You can use notations as L<new()|/new> constructor.
-
-Return value is the same as when an argument was not passed.
-
-=head3 C<< target >>
-
-    $target_notation = $converter->target;
-
-Returns target notation as a scalar.
-
-    $target_notation = $converter->target($notation);
-
-Accepts a string as target notation.
-You can use notations as L<new()|/new> constructor.
-
-Return value is the same as when an argument was not passed.
-
 =head2 Utilities
 
 =head3 C<< all_sources >>
@@ -835,39 +836,6 @@ L<http://freshmeat.net/projects/eoconv/>
 
 None reported.
 
-=head1 TO DO
-
-=over 4
-
-=item *
-
-More tests
-
-=item *
-
-Less dependencies
-
-=item *
-
-To provide an API to add user's notation
-
-=item *
-
-To correctly treat words such as C<flughaveno> (C<flug/haven/o>)
-in L<'postfix_h' notation|/postfix_x> with user's lexicon
-
-=item *
-
-To correctly treat words such as C<ankaŭ>
-in L<'zamenhof' notation|/zamenhof> with user's lexicon
-
-=item *
-
-To release a L<Moose|Moose> friendly class
-such as C<Lingua::EO::Orthography::Moosified>
-
-=back
-
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
@@ -940,6 +908,39 @@ below is the C<Devel::Cover> summary report on this distribution's test suite.
  Total                         100.0  100.0  100.0  100.0  100.0  100.0  100.0
  ---------------------------- ------ ------ ------ ------ ------ ------ ------
 
+=head1 TO DO
+
+=over 4
+
+=item *
+
+More tests
+
+=item *
+
+Less dependencies
+
+=item *
+
+To provide an API to add user's notation
+
+=item *
+
+To correctly treat words such as C<flughaveno> (C<flug/haven/o>)
+in L<'postfix_h' notation|/postfix_x> with user's lexicon
+
+=item *
+
+To correctly treat words such as C<ankaﾅｭ>
+in L<'zamenhof' notation|/zamenhof> with user's lexicon
+
+=item *
+
+To release a L<Moose|Moose> friendly class
+such as C<Lingua::EO::Orthography::Moosified>
+
+=back
+
 =head1 AUTHOR
 
 =over 4
@@ -947,7 +948,7 @@ below is the C<Devel::Cover> summary report on this distribution's test suite.
 =item MORIYA Masaki, alias Gardejo
 
 C<< <moriya at cpan dot org> >>,
-L<http://ttt.ermitejo.com/>
+L<http://gardejo.org/>
 
 =back
 
